from setuptools import setup

setup(name='distributions_acp',
      version='1.0',
      description='Gaussian distributions',
      packages=['distributions_acp'],
      author = 'Andrej Cop Prek',
      author_email = 'andrej.prek91@gmail.com',
      zip_safe=False)
